You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@manifoldcf.apache.org by kw...@apache.org on 2011/02/01 00:07:21 UTC

svn commit: r1065844 - in /incubator/lcf/trunk: ./ connectors/activedirectory/ connectors/documentum/ connectors/filenet/ connectors/filesystem/ connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/ connec...

Author: kwright
Date: Mon Jan 31 23:07:19 2011
New Revision: 1065844

URL: http://svn.apache.org/viewvc?rev=1065844&view=rev
Log:
Fix for CONNECTORS-154.  Add a separate target that will run tests in the PostgreSQL database.

Added:
    incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/SanityPostgresql.java
      - copied, changed from r1064159, incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/Sanity.java
    incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/TestBasePostgresql.java
      - copied, changed from r1064159, incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/TestBase.java
    incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/SanityPostgresql.java
      - copied, changed from r1064159, incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/Sanity.java
    incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/TestBasePostgresql.java
      - copied, changed from r1064159, incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/TestBase.java
    incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/core/tests/TestBasePostgresql.java
      - copied, changed from r1065590, incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/core/tests/TestBase.java
    incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/SanityPostgresql.java
      - copied, changed from r1064159, incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/Sanity.java
    incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestBasePostgresql.java
      - copied, changed from r1064159, incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestBase.java
    incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestConnectorBasePostgresql.java
      - copied, changed from r1064159, incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestConnectorBase.java
    incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/APISanityPostgresql.java
      - copied, changed from r1064159, incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/APISanity.java
    incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/ExpirationPostgresql.java
      - copied, changed from r1064159, incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/Expiration.java
    incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/HopcountPostgresql.java
      - copied, changed from r1064159, incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/Hopcount.java
    incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/SanityPostgresql.java
      - copied, changed from r1064159, incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/Sanity.java
    incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/TestBasePostgresql.java
      - copied, changed from r1064159, incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/TestBase.java
Modified:
    incubator/lcf/trunk/CHANGES.txt
    incubator/lcf/trunk/build.xml
    incubator/lcf/trunk/connectors/activedirectory/build.xml
    incubator/lcf/trunk/connectors/documentum/build.xml
    incubator/lcf/trunk/connectors/filenet/build.xml
    incubator/lcf/trunk/connectors/filesystem/build.xml
    incubator/lcf/trunk/connectors/gts/build.xml
    incubator/lcf/trunk/connectors/jcifs/build.xml
    incubator/lcf/trunk/connectors/jdbc/build.xml
    incubator/lcf/trunk/connectors/livelink/build.xml
    incubator/lcf/trunk/connectors/memex/build.xml
    incubator/lcf/trunk/connectors/meridio/build.xml
    incubator/lcf/trunk/connectors/nullauthority/build.xml
    incubator/lcf/trunk/connectors/nulloutput/build.xml
    incubator/lcf/trunk/connectors/rss/build.xml
    incubator/lcf/trunk/connectors/sharepoint/build.xml
    incubator/lcf/trunk/connectors/solr/build.xml
    incubator/lcf/trunk/connectors/webcrawler/build.xml
    incubator/lcf/trunk/framework/build.xml

Modified: incubator/lcf/trunk/CHANGES.txt
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/CHANGES.txt?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/CHANGES.txt (original)
+++ incubator/lcf/trunk/CHANGES.txt Mon Jan 31 23:07:19 2011
@@ -3,9 +3,13 @@ $Id$
 
 ==================  0.2-dev ==================
 
+CONNECTORS-154: Add an ant target, and tests, that work against the
+postgresql database.
+(Karl Wright)
+
 CONNECTORS-155: Fix a query bug with fetching the job status of a single,
 specified job.
-(Karl Wright
+(Karl Wright)
 
 CONNECTORS-148: Intermittent failures creating the PostgreSQL database
 still occurring; traced the problem this time to PostgreSQL not accepting

Modified: incubator/lcf/trunk/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/build.xml (original)
+++ incubator/lcf/trunk/build.xml Mon Jan 31 23:07:19 2011
@@ -133,6 +133,10 @@
         <ant dir="framework" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-framework" depends="setup-framework">
+        <ant dir="framework" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-activedirectory-connector" depends="build-framework">
         <mkdir dir="connectors/activedirectory/lib"/>
         <copy todir="connectors/activedirectory/lib">
@@ -161,11 +165,15 @@
     <target name="build-tests-activedirectory-connector" depends="setup-activedirectory-connector,setup-activedirectory-connector-tests">
         <ant dir="connectors/activedirectory" target="build-tests"/>
     </target>
-    
+
     <target name="run-tests-activedirectory-connector" depends="setup-activedirectory-connector,setup-activedirectory-connector-tests">
         <ant dir="connectors/activedirectory" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-activedirectory-connector" depends="setup-activedirectory-connector,setup-activedirectory-connector-tests">
+        <ant dir="connectors/activedirectory" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-documentum-connector" depends="build-framework">
         <mkdir dir="connectors/documentum/lib"/>
         <copy todir="connectors/documentum/lib">
@@ -199,6 +207,10 @@
         <ant dir="connectors/documentum" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-documentum-connector" depends="setup-documentum-connector,setup-documentum-connector-tests">
+        <ant dir="connectors/documentum" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-filenet-connector" depends="build-framework">
         <mkdir dir="connectors/filenet/lib"/>
         <copy todir="connectors/filenet/lib">
@@ -232,6 +244,10 @@
         <ant dir="connectors/filenet" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-filenet-connector" depends="setup-filenet-connector,setup-filenet-connector-tests">
+        <ant dir="connectors/filenet" target="run-tests"/>
+    </target>
+
     <target name="setup-filesystem-connector" depends="build-framework">
         <mkdir dir="connectors/filesystem/lib"/>
         <copy todir="connectors/filesystem/lib">
@@ -265,6 +281,10 @@
         <ant dir="connectors/filesystem" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-filesystem-connector" depends="setup-filesystem-connector,setup-filesystem-connector-tests">
+        <ant dir="connectors/filesystem" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-gts-connector" depends="build-framework">
         <mkdir dir="connectors/gts/lib"/>
         <copy todir="connectors/gts/lib">
@@ -301,6 +321,10 @@
         <ant dir="connectors/gts" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-gts-connector" depends="setup-gts-connector,setup-gts-connector-tests">
+        <ant dir="connectors/gts" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-jcifs-connector" depends="build-framework">
         <mkdir dir="connectors/jcifs/lib"/>
         <copy todir="connectors/jcifs/lib">
@@ -332,6 +356,10 @@
         <ant dir="connectors/jcifs" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-jcifs-connector" depends="setup-jcifs-connector,setup-jcifs-connector-tests">
+        <ant dir="connectors/jcifs" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-jdbc-connector" depends="build-framework">
         <mkdir dir="connectors/jdbc/lib"/>
         <copy todir="connectors/jdbc/lib">
@@ -365,6 +393,10 @@
         <ant dir="connectors/jdbc" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-jdbc-connector" depends="setup-jdbc-connector,setup-jdbc-connector-tests">
+        <ant dir="connectors/jdbc" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-livelink-connector" depends="build-framework">
         <mkdir dir="connectors/livelink/lib"/>
         <copy todir="connectors/livelink/lib">
@@ -398,6 +430,10 @@
         <ant dir="connectors/livelink" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-livelink-connector" depends="setup-livelink-connector,setup-livelink-connector-tests">
+        <ant dir="connectors/livelink" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-solr-connector" depends="build-framework">
         <mkdir dir="connectors/solr/lib"/>
         <copy todir="connectors/solr/lib">
@@ -431,6 +467,10 @@
         <ant dir="connectors/solr" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-solr-connector" depends="setup-solr-connector,setup-solr-connector-tests">
+        <ant dir="connectors/solr" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-memex-connector" depends="build-framework">
         <mkdir dir="connectors/memex/lib"/>
         <copy todir="connectors/memex/lib">
@@ -464,6 +504,10 @@
         <ant dir="connectors/memex" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-memex-connector" depends="setup-memex-connector,setup-memex-connector-tests">
+        <ant dir="connectors/memex" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-meridio-connector" depends="build-framework">
         <mkdir dir="connectors/meridio/lib"/>
         <copy todir="connectors/meridio/lib">
@@ -507,6 +551,10 @@
         <ant dir="connectors/meridio" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-meridio-connector" depends="setup-meridio-connector,setup-meridio-connector-tests">
+        <ant dir="connectors/meridio" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-nullauthority-connector" depends="build-framework">
         <mkdir dir="connectors/nullauthority/lib"/>
         <copy todir="connectors/nulloutput/lib">
@@ -540,6 +588,10 @@
         <ant dir="connectors/nullauthority" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-nullauthority-connector" depends="setup-nullauthority-connector,setup-nullauthority-connector-tests">
+        <ant dir="connectors/nullauthority" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-nulloutput-connector" depends="build-framework">
         <mkdir dir="connectors/nulloutput/lib"/>
         <copy todir="connectors/nulloutput/lib">
@@ -573,6 +625,10 @@
         <ant dir="connectors/nulloutput" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-nulloutput-connector" depends="setup-nulloutput-connector,setup-nulloutput-connector-tests">
+        <ant dir="connectors/nulloutput" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-rss-connector" depends="build-framework">
         <mkdir dir="connectors/rss/lib"/>
         <copy todir="connectors/rss/lib">
@@ -606,6 +662,10 @@
         <ant dir="connectors/rss" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-rss-connector" depends="setup-rss-connector,setup-rss-connector-tests">
+        <ant dir="connectors/rss" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-sharepoint-connector" depends="build-framework">
         <mkdir dir="connectors/sharepoint/lib"/>
         <copy todir="connectors/sharepoint/lib">
@@ -647,6 +707,10 @@
         <ant dir="connectors/sharepoint" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-sharepoint-connector" depends="setup-sharepoint-connector,setup-sharepoint-connector-tests">
+        <ant dir="connectors/sharepoint" target="run-tests-postgresql"/>
+    </target>
+
     <target name="setup-webcrawler-connector" depends="build-framework">
         <mkdir dir="connectors/webcrawler/lib"/>
         <copy todir="connectors/webcrawler/lib">
@@ -680,6 +744,10 @@
         <ant dir="connectors/webcrawler" target="run-tests"/>
     </target>
 
+    <target name="run-tests-postgresql-webcrawler-connector" depends="setup-webcrawler-connector,setup-webcrawler-connector-tests">
+        <ant dir="connectors/webcrawler" target="run-tests-postgresql"/>
+    </target>
+
     <target name="deliver-site-doc" depends="build-site">
           <mkdir dir="dist/doc"/>
           <copy todir="dist/doc">
@@ -1505,12 +1573,84 @@
         </junit>
     </target>
 
+    <target name="run-filesystem-tests-postgresql" depends="compile-filesystem-tests,calculate-filesystem-tests-condition" if="filesystem-tests.include">
+        <mkdir dir="test-postgresql-output/filesystem"/>
+        <junit fork="true" maxmemory="128m" dir="test-postgresql-output/filesystem" showoutput="true" haltonfailure="true">
+            <classpath>
+                <fileset dir="framework/lib">
+                    <include name="*.jar"/>
+                </fileset>
+	      <fileset dir="framework/build/jar">
+		<include name="*.jar"/>
+	      </fileset>
+	      <fileset dir="framework/build/test-jar">
+		<include name="*.jar"/>
+	      </fileset>
+	      <fileset dir="connectors/filesystem/build/jar">
+		<include name="*.jar"/>
+	      </fileset>
+	      <fileset dir="connectors/filesystem/build/test-jar">
+		<include name="*.jar"/>
+	      </fileset>
+	      <fileset dir="connectors/nulloutput/build/jar">
+		<include name="*.jar"/>
+	      </fileset>
+	      <fileset dir="connectors/nulloutput/build/test-jar">
+		<include name="*.jar"/>
+	      </fileset>
+                <pathelement location="build/filesystem-tests/classes"/>
+            </classpath>
+            <test name="org.apache.manifoldcf.filesystem_tests.SanityPostgresql" todir="test-postgresql-output/filesystem"/>
+            <test name="org.apache.manifoldcf.filesystem_tests.APISanityPostgresql" todir="test-postgresql-output/filesystem"/>
+            <test name="org.apache.manifoldcf.filesystem_tests.HopcountPostgresql" todir="test-postgresql-output/filesystem"/>
+            <test name="org.apache.manifoldcf.filesystem_tests.ExpirationPostgresql" todir="test-postgresql-output/filesystem"/>
+            <!-- MHL -->
+        </junit>
+    </target>
+
+    <target name="run-sharepoint-tests-postgresql" depends="compile-sharepoint-tests,calculate-sharepoint-tests-condition" if="sharepoint-tests.include">
+        <mkdir dir="test-postgresql-output/sharepoint"/>
+        <junit fork="true" maxmemory="128m" dir="test-postgresql-output/sharepoint" showoutput="true" haltonfailure="true">
+            <classpath>
+                <fileset dir="framework/lib">
+                    <include name="*.jar"/>
+                </fileset>
+	      <fileset dir="framework/build/jar">
+		<include name="*.jar"/>
+	      </fileset>
+	      <fileset dir="framework/build/test-jar">
+		<include name="*.jar"/>
+	      </fileset>
+	      <fileset dir="connectors/sharepoint/build/jar">
+		<include name="*.jar"/>
+	      </fileset>
+	      <fileset dir="connectors/sharepoint/build/test-jar">
+		<include name="*.jar"/>
+	      </fileset>
+	      <fileset dir="connectors/nulloutput/build/jar">
+		<include name="*.jar"/>
+	      </fileset>
+	      <fileset dir="connectors/nulloutput/build/test-jar">
+		<include name="*.jar"/>
+	      </fileset>
+                <pathelement location="build/sharepoint-tests/classes"/>
+            </classpath>
+            <!-- MHL -->
+        </junit>
+    </target>
+
     <target name="run-tests-open-connectors" depends="run-tests-activedirectory-connector,run-tests-filesystem-connector,run-tests-nullauthority-connector,run-tests-nulloutput-connector,run-tests-rss-connector,run-tests-solr-connector,run-tests-webcrawler-connector,run-tests-jdbc-connector"/>
     <target name="run-tests-lgpl-connectors" depends="run-tests-jcifs-connector"/>
     <target name="run-tests-proprietary-connectors" depends="run-tests-documentum-connector,run-tests-filenet-connector,run-tests-livelink-connector,run-tests-memex-connector,run-tests-meridio-connector,run-tests-sharepoint-connector"/>
     
     <target name="end-to-end-tests" depends="run-filesystem-tests,run-sharepoint-tests"/>
+
+    <target name="run-tests-postgresql-open-connectors" depends="run-tests-postgresql-activedirectory-connector,run-tests-postgresql-filesystem-connector,run-tests-postgresql-nullauthority-connector,run-tests-postgresql-nulloutput-connector,run-tests-postgresql-rss-connector,run-tests-postgresql-solr-connector,run-tests-postgresql-webcrawler-connector,run-tests-postgresql-jdbc-connector"/>
+    <target name="run-tests-postgresql-lgpl-connectors" depends="run-tests-postgresql-jcifs-connector"/>
+    <target name="run-tests-postgresql-proprietary-connectors" depends="run-tests-postgresql-documentum-connector,run-tests-postgresql-filenet-connector,run-tests-postgresql-livelink-connector,run-tests-postgresql-memex-connector,run-tests-postgresql-meridio-connector,run-tests-postgresql-sharepoint-connector"/>
     
+    <target name="end-to-end-tests-postgresql" depends="run-filesystem-tests-postgresql,run-sharepoint-tests-postgresql"/>
+
     <target name="deliver-open-connectors" depends="deliver-nullauthority-connector,deliver-activedirectory-connector,deliver-filesystem-connector,deliver-rss-connector,deliver-webcrawler-connector,deliver-jdbc-connector"/>
     <target name="deliver-open-connectors-doc" depends="deliver-nullauthority-connector-doc,deliver-activedirectory-connector-doc,deliver-filesystem-connector-doc,deliver-rss-connector-doc,deliver-webcrawler-connector-doc,deliver-jdbc-connector-doc"/>
     
@@ -1600,7 +1740,9 @@
     
     <target name="test" depends="run-tests-framework,run-tests-open-connectors,run-tests-lgpl-connectors,run-tests-proprietary-connectors,end-to-end-tests"/>
 
-    <target name="all" depends="build,javadoc,doc,image,test"/>
+    <target name="test-pg" depends="run-tests-postgresql-framework,run-tests-postgresql-open-connectors,run-tests-postgresql-lgpl-connectors,run-tests-postgresql-proprietary-connectors,end-to-end-tests-postgresql"/>
+
+    <target name="all" depends="build,javadoc,doc,image,test,test-pg"/>
 
     <target name="help">
       <echo level="info">
@@ -1614,13 +1756,14 @@ build   - Build executable code, jars, p
           under the 'dist' directory
 javadoc - Create the javadocs, under the 'dist/doc' directory
 test    - Compile and run tests for all connectors and framework
+test-pg - Compile and run postgresql-based tests (needs Postgresql)
 doc     - Build html site, under the 'dist/doc' directory
           (requires Apache Forrest)
 image   - Build release image, under the '.' directory (requires
           Apache Forrest)
-all     - Do it all (requires Apache Forrest)
+all     - Do it all (requires Apache Forrest and Postgresql)
 
-All targets requiring Apache Forrest also require Sun JDK 1.5.
+Use Apache Forrest version forrest-0.9-dev or higher.
       </echo>
     </target>
 

Modified: incubator/lcf/trunk/connectors/activedirectory/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/activedirectory/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/activedirectory/build.xml (original)
+++ incubator/lcf/trunk/connectors/activedirectory/build.xml Mon Jan 31 23:07:19 2011
@@ -56,6 +56,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/connectors/documentum/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/documentum/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/documentum/build.xml (original)
+++ incubator/lcf/trunk/connectors/documentum/build.xml Mon Jan 31 23:07:19 2011
@@ -222,6 +222,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
 
 </project>

Modified: incubator/lcf/trunk/connectors/filenet/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/filenet/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/filenet/build.xml (original)
+++ incubator/lcf/trunk/connectors/filenet/build.xml Mon Jan 31 23:07:19 2011
@@ -217,6 +217,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/connectors/filesystem/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/filesystem/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/filesystem/build.xml (original)
+++ incubator/lcf/trunk/connectors/filesystem/build.xml Mon Jan 31 23:07:19 2011
@@ -83,9 +83,24 @@
             <!-- MHL -->
         </junit>
     </target>
+    
+    <target name="run-tests-postgresql" depends="compile-tests">
+        <mkdir dir="test-output-postgresql"/>
+        <junit fork="true" maxmemory="128m" dir="test-output-postgresql" showoutput="true" haltonfailure="true">
+            <classpath>
+                <fileset dir="lib">
+                    <include name="*.jar"/>
+                </fileset>
+                <pathelement location="build/connector/classes"/>
+                <pathelement location="build/tests/classes"/>
+            </classpath>
+            <test name="org.apache.manifoldcf.crawler.connectors.filesystem.tests.SanityPostgresql" todir="test-output-postgresql"/>
+            <!-- MHL -->
+        </junit>
+    </target>
 
     <target name="build" depends="lib"/>
     <target name="build-tests" depends="jar-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Copied: incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/SanityPostgresql.java (from r1064159, incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/Sanity.java)
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/SanityPostgresql.java?p2=incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/SanityPostgresql.java&p1=incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/Sanity.java&r1=1064159&r2=1065844&rev=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/Sanity.java (original)
+++ incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/SanityPostgresql.java Mon Jan 31 23:07:19 2011
@@ -28,7 +28,7 @@ import java.util.*;
 import org.junit.*;
 
 /** This is a very basic sanity check */
-public class Sanity extends TestBase
+public class SanityPostgresql extends TestBasePostgresql
 {
   
   @Test

Copied: incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/TestBasePostgresql.java (from r1064159, incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/TestBase.java)
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/TestBasePostgresql.java?p2=incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/TestBasePostgresql.java&p1=incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/TestBase.java&r1=1064159&r2=1065844&rev=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/TestBase.java (original)
+++ incubator/lcf/trunk/connectors/filesystem/tests/src/main/java/org/apache/manifoldcf/crawler/connectors/filesystem/tests/TestBasePostgresql.java Mon Jan 31 23:07:19 2011
@@ -28,7 +28,7 @@ import java.util.*;
 import org.junit.*;
 
 /** This is a testing base class that is responsible for setting up/tearing down the agents framework. */
-public class TestBase extends org.apache.manifoldcf.crawler.tests.TestConnectorBase
+public class TestBasePostgresql extends org.apache.manifoldcf.crawler.tests.TestConnectorBasePostgresql
 {
   
   protected String[] getConnectorNames()

Modified: incubator/lcf/trunk/connectors/gts/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/gts/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/gts/build.xml (original)
+++ incubator/lcf/trunk/connectors/gts/build.xml Mon Jan 31 23:07:19 2011
@@ -61,6 +61,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/connectors/jcifs/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/jcifs/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/jcifs/build.xml (original)
+++ incubator/lcf/trunk/connectors/jcifs/build.xml Mon Jan 31 23:07:19 2011
@@ -72,6 +72,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/connectors/jdbc/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/jdbc/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/jdbc/build.xml (original)
+++ incubator/lcf/trunk/connectors/jdbc/build.xml Mon Jan 31 23:07:19 2011
@@ -59,6 +59,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/connectors/livelink/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/livelink/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/livelink/build.xml (original)
+++ incubator/lcf/trunk/connectors/livelink/build.xml Mon Jan 31 23:07:19 2011
@@ -72,6 +72,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/connectors/memex/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/memex/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/memex/build.xml (original)
+++ incubator/lcf/trunk/connectors/memex/build.xml Mon Jan 31 23:07:19 2011
@@ -72,6 +72,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/connectors/meridio/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/meridio/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/meridio/build.xml (original)
+++ incubator/lcf/trunk/connectors/meridio/build.xml Mon Jan 31 23:07:19 2011
@@ -200,6 +200,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/connectors/nullauthority/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/nullauthority/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/nullauthority/build.xml (original)
+++ incubator/lcf/trunk/connectors/nullauthority/build.xml Mon Jan 31 23:07:19 2011
@@ -56,6 +56,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/connectors/nulloutput/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/nulloutput/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/nulloutput/build.xml (original)
+++ incubator/lcf/trunk/connectors/nulloutput/build.xml Mon Jan 31 23:07:19 2011
@@ -56,6 +56,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/connectors/rss/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/rss/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/rss/build.xml (original)
+++ incubator/lcf/trunk/connectors/rss/build.xml Mon Jan 31 23:07:19 2011
@@ -56,6 +56,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/connectors/sharepoint/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/sharepoint/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/sharepoint/build.xml (original)
+++ incubator/lcf/trunk/connectors/sharepoint/build.xml Mon Jan 31 23:07:19 2011
@@ -158,6 +158,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/connectors/solr/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/solr/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/solr/build.xml (original)
+++ incubator/lcf/trunk/connectors/solr/build.xml Mon Jan 31 23:07:19 2011
@@ -56,6 +56,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/connectors/webcrawler/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/connectors/webcrawler/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/connectors/webcrawler/build.xml (original)
+++ incubator/lcf/trunk/connectors/webcrawler/build.xml Mon Jan 31 23:07:19 2011
@@ -56,6 +56,7 @@
       <mkdir dir="build/test-jar"/>
     </target>
     <target name="run-tests"/>
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="run-tests-postgresql"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Modified: incubator/lcf/trunk/framework/build.xml
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/framework/build.xml?rev=1065844&r1=1065843&r2=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/framework/build.xml (original)
+++ incubator/lcf/trunk/framework/build.xml Mon Jan 31 23:07:19 2011
@@ -465,9 +465,30 @@
             <!-- MHL -->
         </junit>
     </target>
-    
+
+    <target name="run-tests-postgresql" depends="compile-tests">
+        <mkdir dir="test-output-postgresql"/>
+        <junit fork="true" maxmemory="128m" dir="test-output-postgresql" showoutput="true" haltonfailure="true">
+            <classpath>
+                <fileset dir="lib">
+                    <include name="*.jar"/>
+                </fileset>
+                <pathelement location="build/core/classes"/>
+                <pathelement location="build/ui-core/classes"/>
+                <pathelement location="build/agents/classes"/>
+                <pathelement location="build/pull-agent/classes"/>
+                <pathelement location="build/authority-servlet/classes"/>
+                <pathelement location="build/api-servlet/classes"/>
+                <pathelement location="build/tests/classes"/>
+            </classpath>
+            <test name="org.apache.manifoldcf.agents.tests.SanityPostgresql" todir="test-output-postgresql"/>
+            <test name="org.apache.manifoldcf.crawler.tests.SanityPostgresql" todir="test-output-postgresql"/>
+            <!-- MHL -->
+        </junit>
+    </target>
+
     <target name="build" depends="processes,war-authority-service,war-crawler-ui,war-api-service,example"/>
     
-    <target name="all" depends="build,doc,build-tests,run-tests"/>
+    <target name="all" depends="build,doc,build-tests,run-tests,run-tests-postgresql"/>
     
 </project>

Copied: incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/SanityPostgresql.java (from r1064159, incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/Sanity.java)
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/SanityPostgresql.java?p2=incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/SanityPostgresql.java&p1=incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/Sanity.java&r1=1064159&r2=1065844&rev=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/Sanity.java (original)
+++ incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/SanityPostgresql.java Mon Jan 31 23:07:19 2011
@@ -27,7 +27,7 @@ import java.util.*;
 import org.junit.*;
 
 /** This is a very basic sanity check */
-public class Sanity extends TestBase
+public class SanityPostgresql extends TestBasePostgresql
 {
   
   @Test

Copied: incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/TestBasePostgresql.java (from r1064159, incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/TestBase.java)
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/TestBasePostgresql.java?p2=incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/TestBasePostgresql.java&p1=incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/TestBase.java&r1=1064159&r2=1065844&rev=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/TestBase.java (original)
+++ incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/agents/tests/TestBasePostgresql.java Mon Jan 31 23:07:19 2011
@@ -27,7 +27,7 @@ import java.util.*;
 import org.junit.*;
 
 /** This is a testing base class that is responsible for setting up/tearing down the agents framework. */
-public class TestBase extends org.apache.manifoldcf.core.tests.TestBase
+public class TestBasePostgresql extends org.apache.manifoldcf.core.tests.TestBasePostgresql
 {
   
   @Before

Copied: incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/core/tests/TestBasePostgresql.java (from r1065590, incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/core/tests/TestBase.java)
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/core/tests/TestBasePostgresql.java?p2=incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/core/tests/TestBasePostgresql.java&p1=incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/core/tests/TestBase.java&r1=1065590&r2=1065844&rev=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/Sanity.java (original)
+++ incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/SanityPostgresql.java Mon Jan 31 23:07:19 2011
@@ -27,7 +27,7 @@ import java.util.*;
 import org.junit.*;
 
 /** This is a very basic sanity check */
-public class Sanity extends TestBase
+public class SanityPostgresql extends TestBasePostgresql
 {
   
   @Test

Copied: incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestBasePostgresql.java (from r1064159, incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestBase.java)
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestBasePostgresql.java?p2=incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestBasePostgresql.java&p1=incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestBase.java&r1=1064159&r2=1065844&rev=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestBase.java (original)
+++ incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestBasePostgresql.java Mon Jan 31 23:07:19 2011
@@ -28,7 +28,7 @@ import java.util.*;
 import org.junit.*;
 
 /** This is a testing base class that is responsible for setting up/tearing down the agents framework. */
-public class TestBase extends org.apache.manifoldcf.agents.tests.TestBase
+public class TestBasePostgresql extends org.apache.manifoldcf.agents.tests.TestBasePostgresql
 {
   
   @Before

Copied: incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestConnectorBasePostgresql.java (from r1064159, incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestConnectorBase.java)
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestConnectorBasePostgresql.java?p2=incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestConnectorBasePostgresql.java&p1=incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestConnectorBase.java&r1=1064159&r2=1065844&rev=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestConnectorBase.java (original)
+++ incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/TestConnectorBasePostgresql.java Mon Jan 31 23:07:19 2011
@@ -29,7 +29,7 @@ import java.util.*;
 import org.junit.*;
 
 /** This is a testing base class that is responsible for setting up/tearing down the agents framework. */
-public class TestConnectorBase extends org.apache.manifoldcf.crawler.tests.TestBase
+public class TestConnectorBasePostgresql extends org.apache.manifoldcf.crawler.tests.TestBasePostgresql
 {
   
   protected String[] getConnectorClasses()

Copied: incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/APISanityPostgresql.java (from r1064159, incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/APISanity.java)
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/APISanityPostgresql.java?p2=incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/APISanityPostgresql.java&p1=incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/APISanity.java&r1=1064159&r2=1065844&rev=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/APISanity.java (original)
+++ incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/APISanityPostgresql.java Mon Jan 31 23:07:19 2011
@@ -28,7 +28,7 @@ import java.util.*;
 import org.junit.*;
 
 /** This is a very basic sanity check */
-public class APISanity extends TestBase
+public class APISanityPostgresql extends TestBasePostgresql
 {
   
   @Before

Copied: incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/ExpirationPostgresql.java (from r1064159, incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/Expiration.java)
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/ExpirationPostgresql.java?p2=incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/ExpirationPostgresql.java&p1=incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/Expiration.java&r1=1064159&r2=1065844&rev=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/Expiration.java (original)
+++ incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/ExpirationPostgresql.java Mon Jan 31 23:07:19 2011
@@ -28,7 +28,7 @@ import java.util.*;
 import org.junit.*;
 
 /** This is a test which checks to see if document expiration works properly. */
-public class Expiration extends TestBase
+public class ExpirationPostgresql extends TestBasePostgresql
 {
   
   @Before

Copied: incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/HopcountPostgresql.java (from r1064159, incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/Hopcount.java)
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/HopcountPostgresql.java?p2=incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/HopcountPostgresql.java&p1=incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/Hopcount.java&r1=1064159&r2=1065844&rev=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/Hopcount.java (original)
+++ incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/HopcountPostgresql.java Mon Jan 31 23:07:19 2011
@@ -28,7 +28,7 @@ import java.util.*;
 import org.junit.*;
 
 /** This is a test which checks to be sure hopcount functionality is working properly. */
-public class Hopcount extends TestBase
+public class HopcountPostgresql extends TestBasePostgresql
 {
   
   @Before

Copied: incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/SanityPostgresql.java (from r1064159, incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/Sanity.java)
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/SanityPostgresql.java?p2=incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/SanityPostgresql.java&p1=incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/Sanity.java&r1=1064159&r2=1065844&rev=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/Sanity.java (original)
+++ incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/SanityPostgresql.java Mon Jan 31 23:07:19 2011
@@ -28,7 +28,7 @@ import java.util.*;
 import org.junit.*;
 
 /** This is a very basic sanity check */
-public class Sanity extends TestBase
+public class SanityPostgresql extends TestBasePostgresql
 {
   
   @Before

Copied: incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/TestBasePostgresql.java (from r1064159, incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/TestBase.java)
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/TestBasePostgresql.java?p2=incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/TestBasePostgresql.java&p1=incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/TestBase.java&r1=1064159&r2=1065844&rev=1065844&view=diff
==============================================================================
--- incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/TestBase.java (original)
+++ incubator/lcf/trunk/tests/filesystem/org/apache/manifoldcf/filesystem_tests/TestBasePostgresql.java Mon Jan 31 23:07:19 2011
@@ -39,7 +39,7 @@ import org.apache.commons.httpclient.*;
 import org.apache.commons.httpclient.methods.*;
 
 /** Tests that run the "agents daemon" should be derived from this */
-public class TestBase extends org.apache.manifoldcf.crawler.tests.TestConnectorBase
+public class TestBasePostgresql extends org.apache.manifoldcf.crawler.tests.TestConnectorBasePostgresql
 {
   public static final String agentShutdownSignal = "agent-process";
   public static final int testPort = 8346;
--- incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/core/tests/TestBase.java (original)
+++ incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/core/tests/TestBasePostgresql.java Mon Jan 31 23:07:19 2011
@@ -25,9 +25,12 @@ import java.io.*;
 import java.util.*;
 import org.junit.*;
 
-/** This is a testing base class that is responsible for setting up/tearing down the core Derby database. */
-public class TestBase
+/** This is a testing base class that is responsible for setting up/tearing down the core Postgresql database. */
+public class TestBasePostgresql
 {
+  protected final static String SUPER_USER_NAME = "postgres";
+  protected final static String SUPER_USER_PASSWORD = "postgres";
+  
   protected File currentPath = null;
   protected File configFile = null;
   protected File loggingFile = null;
@@ -93,8 +96,9 @@ public class TestBase
     writeFile(configFile,
       "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n" +
       "<configuration>\n"+
-      "  <property name=\"org.apache.manifoldcf.databaseimplementationclass\" value=\"org.apache.manifoldcf.core.database.DBInterfaceDerby\"/>\n" +
-      "  <property name=\"org.apache.manifoldcf.derbydatabasepath\" value=\""+currentPathString.replaceAll("\\\\","/")+"\"/>\n" +
+      "  <property name=\"org.apache.manifoldcf.databaseimplementationclass\" value=\"org.apache.manifoldcf.core.database.DBInterfacePostgreSQL\"/>\n" +
+      "  <property name=\"org.apache.manifoldcf.database.name\" value=\"testdb\"/>\n" +
+      "  <property name=\"org.apache.manifoldcf.database.username\" value=\"testuser\"/>\n" +
       "  <property name=\"org.apache.manifoldcf.logconfigfile\" value=\""+loggingFile.getAbsolutePath().replaceAll("\\\\","/")+"\"/>\n" +
       "</configuration>\n");
 
@@ -102,7 +106,7 @@ public class TestBase
     IThreadContext tc = ThreadContextFactory.make();
     
     // Create the database
-    ManifoldCF.createSystemDatabase(tc,"","");
+    ManifoldCF.createSystemDatabase(tc,SUPER_USER_NAME,SUPER_USER_PASSWORD);
 
   }
   
@@ -131,7 +135,7 @@ public class TestBase
       IThreadContext tc = ThreadContextFactory.make();
       
       // Remove the database
-      ManifoldCF.dropSystemDatabase(tc,"","");
+      ManifoldCF.dropSystemDatabase(tc,SUPER_USER_NAME,SUPER_USER_PASSWORD);
       
       // Get rid of the property and logging files.
       logOutputFile.delete();

Copied: incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/SanityPostgresql.java (from r1064159, incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/Sanity.java)
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/SanityPostgresql.java?p2=incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/SanityPostgresql.java&p1=incubator/lcf/trunk/framework/tests/src/main/java/org/apache/manifoldcf/crawler/tests/Sanity.java&r1=1064159&r2=1065844&rev=1065844&view=diff
==============================================================================